timesignaturetools.establish_metrical_hierarchy
===============================================

.. autofunction:: abjad.tools.timesignaturetools.establish_metrical_hierarchy.establish_metrical_hierarchy
   :noindex:
